from _typeshed import Incomplete
from contextlib import AbstractContextManager
from typing import Any, NamedTuple

from psutil._common import (
    FREEBSD as FREEBSD,
    NETBSD as NETBSD,
    OPENBSD as OPENBSD,
    AccessDenied as AccessDenied,
    NoSuchProcess as NoSuchProcess,
    ZombieProcess as ZombieProcess,
    conn_tmap as conn_tmap,
    conn_to_ntuple as conn_to_ntuple,
    memoize as memoize,
    pio,
    usage_percent as usage_percent,
)

__extra__all__: Any
PROC_STATUSES: Any
TCP_STATUSES: Any
PAGESIZE: Any
AF_LINK: Any
HAS_PER_CPU_TIMES: Any
HAS_PROC_NUM_THREADS: Any
HAS_PROC_OPEN_FILES: Any
HAS_PROC_NUM_FDS: Any
kinfo_proc_map: Any

class svmem(NamedTuple):
    total: int
    available: int
    percent: float
    used: int
    free: int
    active: int
    inactive: int
    buffers: int
    cached: int
    shared: int
    wired: int

class scputimes(NamedTuple):
    user: Any
    nice: Any
    system: Any
    idle: Any
    irq: Any

class pmem(NamedTuple):
    rss: Any
    vms: Any
    text: Any
    data: Any
    stack: Any

pfullmem = pmem

class pcputimes(NamedTuple):
    user: Any
    system: Any
    children_user: Any
    children_system: Any

class pmmap_grouped(NamedTuple):
    path: Any
    rss: Any
    private: Any
    ref_count: Any
    shadow_count: Any

class pmmap_ext(NamedTuple):
    addr: Any
    perms: Any
    path: Any
    rss: Any
    private: Any
    ref_count: Any
    shadow_count: Any

class sdiskio(NamedTuple):
    read_count: Any
    write_count: Any
    read_bytes: Any
    write_bytes: Any
    read_time: Any
    write_time: Any
    busy_time: Any

def virtual_memory() -> svmem: ...
def swap_memory(): ...
def cpu_times(): ...
def per_cpu_times(): ...
def cpu_count_logical(): ...
def cpu_count_cores() -> int | None: ...
def cpu_stats(): ...
def disk_partitions(all: bool = ...): ...

disk_usage: Any
disk_io_counters: Any
net_io_counters: Any
net_if_addrs: Any

def net_if_stats(): ...
def net_connections(kind): ...
def sensors_battery(): ...
def sensors_temperatures(): ...
def cpu_freq(): ...
def boot_time(): ...
def users(): ...
def pids(): ...
def pid_exists(pid): ...
def is_zombie(pid): ...
def wrap_exceptions(fun): ...
def wrap_exceptions_procfs(inst) -> AbstractContextManager[None]: ...

class Process:
    pid: Any
    def __init__(self, pid) -> None: ...
    def oneshot(self): ...
    def oneshot_enter(self) -> None: ...
    def oneshot_exit(self) -> None: ...
    def name(self): ...
    def exe(self): ...
    def cmdline(self): ...
    def environ(self): ...
    def terminal(self): ...
    def ppid(self): ...
    def uids(self): ...
    def gids(self): ...
    def cpu_times(self): ...
    def cpu_num(self): ...
    def memory_info(self): ...
    memory_full_info: Any
    def create_time(self): ...
    def num_threads(self): ...
    def num_ctx_switches(self): ...
    def threads(self): ...
    def connections(self, kind: str = ...): ...
    def wait(self, timeout: Incomplete | None = ...): ...
    def nice_get(self): ...
    def nice_set(self, value): ...
    def status(self): ...
    def io_counters(self) -> pio: ...
    def cwd(self): ...

    class nt_mmap_grouped(NamedTuple):
        path: Any
        rss: Any
        private: Any
        ref_count: Any
        shadow_count: Any

    class nt_mmap_ext(NamedTuple):
        addr: Any
        perms: Any
        path: Any
        rss: Any
        private: Any
        ref_count: Any
        shadow_count: Any

    def open_files(self): ...
    def num_fds(self): ...
    def cpu_affinity_get(self): ...
    def cpu_affinity_set(self, cpus) -> None: ...
    def memory_maps(self): ...
    def rlimit(self, resource, limits: Incomplete | None = ...): ...



from builtins import (
    ChildProcessError as ChildProcessError,
    FileExistsError as FileExistsError,
    FileNotFoundError as FileNotFoundError,
    InterruptedError as InterruptedError,
    PermissionError as PermissionError,
    ProcessLookupError as ProcessLookupError,
    range as range,
    super as super,
)
from contextlib import redirect_stderr as redirect_stderr
from functools import lru_cache as lru_cache
from shutil import get_terminal_size as get_terminal_size, which as which
from subprocess import TimeoutExpired
from typing import Literal

PY3: Literal[True]
long = int
xrange = range
unicode = str
basestring = str

def u(s): ...
def b(s): ...

SubprocessTimeoutExpired = TimeoutExpired



from typing import Any

DUPLEX_FULL: int
DUPLEX_HALF: int
DUPLEX_UNKNOWN: int
version: int

def check_pid_range(pid: int, /) -> None: ...
def disk_partitions(*args, **kwargs) -> Any: ...
def linux_sysinfo(*args, **kwargs) -> Any: ...
def net_if_duplex_speed(*args, **kwargs) -> Any: ...
def proc_cpu_affinity_get(*args, **kwargs) -> Any: ...
def proc_cpu_affinity_set(*args, **kwargs) -> Any: ...
def proc_ioprio_get(*args, **kwargs) -> Any: ...
def proc_ioprio_set(*args, **kwargs) -> Any: ...
def set_debug(*args, **kwargs) -> Any: ...
def users(*args, **kwargs) -> Any: ...



from typing import Any

PSUTIL_CONN_NONE: int
SIDL: int
SRUN: int
SSLEEP: int
SSTOP: int
SZOMB: int
TCPS_CLOSED: int
TCPS_CLOSE_WAIT: int
TCPS_CLOSING: int
TCPS_ESTABLISHED: int
TCPS_FIN_WAIT_1: int
TCPS_FIN_WAIT_2: int
TCPS_LAST_ACK: int
TCPS_LISTEN: int
TCPS_SYN_RECEIVED: int
TCPS_SYN_SENT: int
TCPS_TIME_WAIT: int
version: int

def boot_time(*args, **kwargs) -> Any: ...
def check_pid_range(pid: int, /) -> None: ...
def cpu_count_cores(*args, **kwargs) -> Any: ...
def cpu_count_logical(*args, **kwargs) -> Any: ...
def cpu_freq(*args, **kwargs) -> Any: ...
def cpu_stats(*args, **kwargs) -> Any: ...
def cpu_times(*args, **kwargs) -> Any: ...
def disk_io_counters(*args, **kwargs) -> Any: ...
def disk_partitions(*args, **kwargs) -> Any: ...
def disk_usage_used(*args, **kwargs) -> Any: ...
def net_io_counters(*args, **kwargs) -> Any: ...
def per_cpu_times(*args, **kwargs) -> Any: ...
def pids(*args, **kwargs) -> Any: ...
def proc_cmdline(*args, **kwargs) -> Any: ...
def proc_connections(*args, **kwargs) -> Any: ...
def proc_cwd(*args, **kwargs) -> Any: ...
def proc_environ(*args, **kwargs) -> Any: ...
def proc_exe(*args, **kwargs) -> Any: ...
def proc_kinfo_oneshot(*args, **kwargs) -> Any: ...
def proc_memory_uss(*args, **kwargs) -> Any: ...
def proc_name(*args, **kwargs) -> Any: ...
def proc_num_fds(*args, **kwargs) -> Any: ...
def proc_open_files(*args, **kwargs) -> Any: ...
def proc_pidtaskinfo_oneshot(*args, **kwargs) -> Any: ...
def proc_threads(*args, **kwargs) -> Any: ...
def sensors_battery(*args, **kwargs) -> Any: ...
def set_debug(*args, **kwargs) -> Any: ...
def swap_mem(*args, **kwargs) -> Any: ...
def users(*args, **kwargs) -> Any: ...
def virtual_mem(*args, **kwargs) -> Any: ...



from setuptools import setup

name = "types-psutil"
description = "Typing stubs for psutil"
long_description = '''
## Typing stubs for psutil

This is a [PEP 561](https://peps.python.org/pep-0561/)
type stub package for the [`psutil`](https://github.com/giampaolo/psutil) package.
It can be used by type-checking tools like
[mypy](https://github.com/python/mypy/),
[pyright](https://github.com/microsoft/pyright),
[pytype](https://github.com/google/pytype/),
PyCharm, etc. to check code that uses
`psutil`.

This version of `types-psutil` aims to provide accurate annotations
for `psutil==5.9.*`.
The source for this package can be found at
https://github.com/python/typeshed/tree/main/stubs/psutil. All fixes for
types and metadata should be contributed there.

See https://github.com/python/typeshed/blob/main/README.md for more details.
This package was generated from typeshed commit `82d84c758cbfb3ebe8bed63b39354da21e0d3794` and was tested
with mypy 1.9.0, pyright 1.1.354, and
pytype 2024.3.11.
'''.lstrip()

setup(name=name,
      version="5.9.5.20240316",
      description=description,
      long_description=long_description,
      long_description_content_type="text/markdown",
      url="https://github.com/python/typeshed",
      project_urls={
          "GitHub": "https://github.com/python/typeshed",
          "Changes": "https://github.com/typeshed-internal/stub_uploader/blob/main/data/changelogs/psutil.md",
          "Issue tracker": "https://github.com/python/typeshed/issues",
          "Chat": "https://gitter.im/python/typing",
      },
      install_requires=[],
      packages=['psutil-stubs'],
      package_data={'psutil-stubs': ['__init__.pyi', '_common.pyi', '_compat.pyi', '_psaix.pyi', '_psbsd.pyi', '_pslinux.pyi', '_psosx.pyi', '_psposix.pyi', '_pssunos.pyi', '_psutil_linux.pyi', '_psutil_osx.pyi', '_psutil_posix.pyi', '_psutil_windows.pyi', '_pswindows.pyi', 'METADATA.toml']},
      license="Apache-2.0 license",
      python_requires=">=3.8",
      classifiers=[
          "License :: OSI Approved :: Apache Software License",
          "Programming Language :: Python :: 3",
          "Typing :: Stubs Only",
      ]
)



from _typeshed import Incomplete
from typing import Any, NamedTuple

from psutil._common import (
    AccessDenied as AccessDenied,
    NoSuchProcess as NoSuchProcess,
    ZombieProcess as ZombieProcess,
    conn_tmap as conn_tmap,
    conn_to_ntuple as conn_to_ntuple,
    isfile_strict as isfile_strict,
    parse_environ_block as parse_environ_block,
    usage_percent as usage_percent,
)

__extra__all__: Any
PAGESIZE: Any
AF_LINK: Any
TCP_STATUSES: Any
PROC_STATUSES: Any
kinfo_proc_map: Any
pidtaskinfo_map: Any

class scputimes(NamedTuple):
    user: Any
    nice: Any
    system: Any
    idle: Any

class svmem(NamedTuple):
    total: int
    available: int
    percent: float
    used: int
    free: int
    active: int
    inactive: int
    wired: int

class pmem(NamedTuple):
    rss: Any
    vms: Any
    pfaults: Any
    pageins: Any

class pfullmem(NamedTuple):
    rss: Incomplete
    vms: Incomplete
    pfaults: Incomplete
    pageins: Incomplete
    uss: Incomplete

def virtual_memory() -> svmem: ...
def swap_memory(): ...
def cpu_times(): ...
def per_cpu_times(): ...
def cpu_count_logical(): ...
def cpu_count_cores() -> int | None: ...
def cpu_stats(): ...
def cpu_freq(): ...

disk_usage: Any
disk_io_counters: Any

def disk_partitions(all: bool = ...): ...
def sensors_battery(): ...

net_io_counters: Any
net_if_addrs: Any

def net_connections(kind: str = ...): ...
def net_if_stats(): ...
def boot_time(): ...
def users(): ...
def pids(): ...

pid_exists: Any

def is_zombie(pid): ...
def wrap_exceptions(fun): ...

class Process:
    pid: Any
    def __init__(self, pid) -> None: ...
    def oneshot_enter(self) -> None: ...
    def oneshot_exit(self) -> None: ...
    def name(self): ...
    def exe(self): ...
    def cmdline(self): ...
    def environ(self): ...
    def ppid(self): ...
    def cwd(self): ...
    def uids(self): ...
    def gids(self): ...
    def terminal(self): ...
    def memory_info(self): ...
    def memory_full_info(self): ...
    def cpu_times(self): ...
    def create_time(self): ...
    def num_ctx_switches(self): ...
    def num_threads(self): ...
    def open_files(self): ...
    def connections(self, kind: str = ...): ...
    def num_fds(self): ...
    def wait(self, timeout: Incomplete | None = ...): ...
    def nice_get(self): ...
    def nice_set(self, value): ...
    def status(self): ...
    def threads(self): ...
